@@ -22,5 +22,9 @@ module.exports = {
     ArrayGetSize: 20,
     ArrayGetRank: 21,
     ArraySetItem: 22,
-    Array: 23
+    Array: 23,
+    RetrieveArray: 24,
+    SetInstanceField: 25,
+    InvokeGenericStaticMethod: 26,
+    InvokeGenericMethod:27
 }
\ No newline at end of file
