@@ -12,7 +12,7 @@ class CreateClassInstanceHandler < AbstractCommandHandler
   def create_class_instance(command)
     begin
       if command.payload.length < @required_parameters_count
-        raise "Class instance parameters mismatch"
+        raise ArgumentError.new "Class instance parameters mismatch"
       end
       if command.payload.length > 1
         constructor_arguments = command.payload[1..]
