@@ -14,6 +14,7 @@ use aliased 'Javonet::Core::Handler::CommandHandler::GetTypeHandler' => 'GetType
 use aliased 'Javonet::Core::Exception::Exception' => 'Exception';
 use aliased 'Javonet::Core::Handler::CommandHandler::CastingHandler' => 'CastingHandler';
 use aliased 'Javonet::Core::Handler::CommandHandler::GetInstanceFieldHandler' => 'GetInstanceFieldHandler';
+use aliased 'Javonet::Core::Handler::CommandHandler::SetInstanceFieldHandler' => 'SetInstanceFieldHandler';
 use aliased 'Javonet::Core::Handler::CommandHandler::DestructReferenceHandler' => 'DestructReferenceHandler';
 use aliased 'Javonet::Core::Exception::ExceptionSerializer' => 'ExceptionSerializer';
 use aliased 'Javonet::Core::Handler::CommandHandler::ArrayGetItemHandler' => 'ArrayGetItemHandler';
@@ -39,6 +40,7 @@ my $resolve_instance_handler = ResolveInstanceHandler->new();
 my $get_type_handler = GetTypeHandler->new();
 my $casting_handler = CastingHandler->new();
 my $get_instance_field_handler = GetInstanceFieldHandler->new();
+my $set_instance_field_handler = SetInstanceFieldHandler->new();
 my $destruct_reference_handler = DestructReferenceHandler->new();
 my $array_get_item_handler = ArrayGetItemHandler->new();
 my $array_get_size_handler = ArrayGetSizeHandler->new();
@@ -86,6 +88,10 @@ Javonet::Core::Handler::HandlerDictionary::add_handler_to_dict(
     Javonet::Sdk::Core::PerlCommandType::get_command_type('GetInstanceField'),
     $get_instance_field_handler
 );
+Javonet::Core::Handler::HandlerDictionary::add_handler_to_dict(
+    Javonet::Sdk::Core::PerlCommandType::get_command_type('SetInstanceField'),
+    $set_instance_field_handler
+);
 Javonet::Core::Handler::HandlerDictionary::add_handler_to_dict(
     Javonet::Sdk::Core::PerlCommandType::get_command_type('DestructReference'),
     $destruct_reference_handler
@@ -103,7 +109,7 @@ Javonet::Core::Handler::HandlerDictionary::add_handler_to_dict(
     $array_get_rank_handler
 );
 Javonet::Core::Handler::HandlerDictionary::add_handler_to_dict(
-    Javonet::Sdk::Core::PerlCommandType::get_command_type('ArraySetSize'),
+    Javonet::Sdk::Core::PerlCommandType::get_command_type('ArraySetItem'),
     $array_set_item_handler
 );
 
