@@ -260,6 +260,38 @@ sub set_index {
     );
 }
 
+sub invoke_generic_static_method {
+    my ($self, @arguments) = @_;
+    my $command = Javonet::Sdk::Core::PerlCommand->new(
+        runtime      => $self->{runtime_lib},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('InvokeGenericStaticMethod'),
+        payload      => \@arguments
+    );
+    return Javonet::Sdk::Internal::InvocationContext->new(
+        $self->{runtime_lib},
+        $self->{connection_type},
+        $self->{tcp_address},
+        $self->build_command($command),
+        0
+    );
+}
+
+sub invoke_generic_method {
+    my ($self, @arguments) = @_;
+    my $command = Javonet::Sdk::Core::PerlCommand->new(
+        runtime      => $self->{runtime_lib},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('InvokeGenericMethod'),
+        payload      => \@arguments
+    );
+    return Javonet::Sdk::Internal::InvocationContext->new(
+        $self->{runtime_lib},
+        $self->{connection_type},
+        $self->{tcp_address},
+        $self->build_command($command),
+        0
+    );
+}
+
 #@override
 sub get_value {
     my $self = shift;
